;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elisp-dev-mcp" "20251004.1154"
  "MCP server for agentic Elisp development."
  '((emacs          "27.1")
    (mcp-server-lib "0.2.0"))
  :url "https://github.com/laurynas-biveinis/elisp-dev-mcp"
  :commit "05bc3ca843ebbb243c22d2a44ea2fb47884f35e6"
  :revdesc "05bc3ca843eb"
  :keywords '("tools" "development"))
